==> artery-document-domain-1.4.14-sources.jar: com/xforceplus/ultraman/app/arterydocument/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.arterydocument.metadata;

/**
 *
 * @author ultraman
 * @since 2023-11-22
 */

public class PageMeta {
    public interface GoodsReceiveNote {
        static String code() {
            return "goodsReceiveNote";
        }
        static String name() {
            return "收货单列表";
        }
    }
    public interface Po {
        static String code() {
            return "po";
        }
        static String name() {
            return "采购订单列表";
        }
    }
    public interface Ir {
        static String code() {
            return "ir";
        }
        static String name() {
            return "库存单列表";
        }
    }
    public interface Pos {
        static String code() {
            return "pos";
        }
        static String name() {
            return "POS销售单列表";
        }
    }
    public interface Rtv {
        static String code() {
            return "rtv";
        }
        static String name() {
            return "退货单列表";
        }
    }
    public interface Settlement {
        static String code() {
            return "settlement";
        }
        static String name() {
            return "结算单查询";
        }
    }
    public interface So {
        static String code() {
            return "so";
        }
        static String name() {
            return "销售出库单列表";
        }
    }
    public interface AccountingDocCheck {
        static String code() {
            return "accountingDocCheck";
        }
        static String name() {
            return "凭证管理";
        }
    }
    public interface BillingManageMent {
        static String code() {
            return "billingManageMent";
        }
        static String name() {
            return "billing单管理";
        }
    }
    public interface BillingDiscountDetail {
        static String code() {
            return "billingDiscountDetail";
        }
        static String name() {
            return "billing折扣明细";
        }
    }
    public interface SalesOrder {
        static String code() {
            return "salesOrder";
        }
        static String name() {
            return "销售订单查询";
        }
    }
    public interface TenantTransferQuery {
        static String code() {
            return "tenantTransferQuery";
        }
        static String name() {
            return "租户单据转换查询";
        }
    }
    public interface CustomBillingOp {
        static String code() {
            return "customBillingOp";
        }
        static String name() {
            return "billing单运维";
        }
    }
    public interface ProductDataAnalysis {
        static String code() {
            return "productDataAnalysis";
        }
        static String name() {
            return "商品市场数据分析";
        }
    }
    public interface AddressDemo {
        static String code() {
            return "addressDemo";
        }
        static String name() {
            return "地址Demo";
        }
    }
}

==> artery-document-domain-1.5.0-sources.jar: com/xforceplus/ultraman/app/arterydocument/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.arterydocument.metadata;

/**
 *
 * @author ultraman
 * @since 2023-12-05
 */

public class PageMeta {
    public interface So {
        static String code() {
            return "so";
        }
        static String name() {
            return "销售出库单列表";
        }
    }
    public interface Ir {
        static String code() {
            return "ir";
        }
        static String name() {
            return "库存单列表";
        }
    }
    public interface AccountingDocCheck {
        static String code() {
            return "accountingDocCheck";
        }
        static String name() {
            return "凭证管理";
        }
    }
    public interface BillingDiscountDetail {
        static String code() {
            return "billingDiscountDetail";
        }
        static String name() {
            return "billing折扣明细";
        }
    }
    public interface Settlement {
        static String code() {
            return "settlement";
        }
        static String name() {
            return "结算单查询";
        }
    }
    public interface BillingManageMent {
        static String code() {
            return "billingManageMent";
        }
        static String name() {
            return "billing单管理";
        }
    }
    public interface Rtv {
        static String code() {
            return "rtv";
        }
        static String name() {
            return "退货单列表";
        }
    }
    public interface GoodsReceiveNote {
        static String code() {
            return "goodsReceiveNote";
        }
        static String name() {
            return "收货单列表";
        }
    }
    public interface Po {
        static String code() {
            return "po";
        }
        static String name() {
            return "采购订单列表";
        }
    }
    public interface AddressDemo {
        static String code() {
            return "addressDemo";
        }
        static String name() {
            return "地址Demo";
        }
    }
    public interface ProductDataAnalysis {
        static String code() {
            return "productDataAnalysis";
        }
        static String name() {
            return "商品市场数据分析";
        }
    }
    public interface CustomBillingOp {
        static String code() {
            return "customBillingOp";
        }
        static String name() {
            return "billing单运维";
        }
    }
    public interface SalesOrder {
        static String code() {
            return "salesOrder";
        }
        static String name() {
            return "销售订单查询";
        }
    }
    public interface SchemaCodeMapping {
        static String code() {
            return "schemaCodeMapping";
        }
        static String name() {
            return "客商场景码配置";
        }
    }
    public interface Tabcode {
        static String code() {
            return "tabcode";
        }
        static String name() {
            return "商品场景码配置";
        }
    }
    public interface TenantTransferQuery {
        static String code() {
            return "tenantTransferQuery";
        }
        static String name() {
            return "租户单据转换查询";
        }
    }
    public interface Pos {
        static String code() {
            return "pos";
        }
        static String name() {
            return "POS销售单列表";
        }
    }
}
